==> trade-center-biz-0.1.1.qb-20160922.081351-7-sources.jar: cn/com/duiba/order/center/biz/remoteservice/RemoteOrderJumpServiceImpl.java <==
package cn.com.duiba.order.center.biz.remoteservice;

import cn.com.duiba.order.center.api.remoteservice.RemoteOrderJumpService;
import cn.com.duiba.order.center.biz.service.mainorder.OrderJumpService;
import cn.com.duiba.service.exception.BusinessException;
import cn.com.duiba.wolf.dubbo.DubboResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;


/**
 * Created by yansen on 16/9/21.
 */
@Service
public class RemoteOrderJumpServiceImpl implements RemoteOrderJumpService {

    @Autowired
    private OrderJumpService orderJumpService;

    /**
     * 创建订单started->兑吧付款complete
     *
     * @param orderId
     * @param consumerId
     */
    @Override
    public DubboResult<Integer> jumpCreateStarted2DuibaPayComplete(Long orderId, Long consumerId) {
        try {
            int ret=orderJumpService.jumpCreateStarted2DuibaPayComplete(orderId,consumerId);
            return DubboResult.successResult(ret);
        } catch (BusinessException e) {
            return DubboResult.failResult(e.getMessage());
        }
    }

    /**
     * 创建订单started->开发都付款完成 complete
     *
     * @param orderId
     * @param consumerId
     */
    @Override
    public DubboResult<Integer> jumpCreateStarted2DeveloperPayComplete(Long orderId, Long consumerId) {
        try {
            int ret=orderJumpService.jumpCreateStarted2DeveloperPayComplete(orderId,consumerId);
            return DubboResult.successResult(ret);
        } catch (BusinessException e) {
            return DubboResult.failResult(e.getMessage());
        }
    }

    /**
     * 开发者付款  started-> 兑吧付款完成 complete
     *
     * @param orderId
     * @param consumerId
     */
    @Override
    public DubboResult<Integer> jumpDeveloperPayStarted2DuibaPayComplete(Long orderId, Long consumerId) {
        try {
            int ret=orderJumpService.jumpDeveloperPayStarted2DuibaPayComplete(orderId,consumerId);
            return DubboResult.successResult(ret);
        } catch (BusinessException e) {
            return DubboResult.failResult(e.getMessage());
        }
    }

    /**
     * 扣积分started->用户付款complete
     *
     * @param orderId
     * @param consumerId
     */
    @Override
    public DubboResult<Integer> jumpConsumeCreditsStarted2ConsumerPayComplete(Long orderId, Long consumerId) {
        try {
            int ret=orderJumpService.jumpConsumeCreditsStarted2ConsumerPayComplete(orderId,consumerId);
            return DubboResult.successResult(ret);
        } catch (BusinessException e) {
            return DubboResult.failResult(e.getMessage());
        }
    }

    /**
     * 扣积分started->审核complete
     *
     * @param orderId
     * @param consumerId
     */
    @Override
    public DubboResult<Integer> jumpConsumeCreditsStarted2AuditComplete(Long orderId, Long consumerId) {
        try {
            int ret=orderJumpService.jumpConsumeCreditsStarted2AuditComplete(orderId,consumerId);
            return DubboResult.successResult(ret);
        } catch (BusinessException e) {
            return DubboResult.failResult(e.getMessage());
        }
    }

    /**
     * 上游兑换started->售后complete
     *
     * @param orderId
     * @param consumerId
     */
    @Override
    public DubboResult<Integer> jumpSupplierExchangeStarted2AfterSendComplete(Long orderId, Long consumerId) {
        try {
            int ret=orderJumpService.jumpSupplierExchangeStarted2AfterSendComplete(orderId,consumerId);
            return DubboResult.successResult(ret);
        } catch (BusinessException e) {
            return DubboResult.failResult(e.getMessage());
        }
    }
}

==> trade-center-biz-0.1.4.3.qb-20161025.062500-2-sources.jar: cn/com/duiba/order/center/biz/remoteservice/RemoteOrderJumpServiceImpl.java <==
package cn.com.duiba.order.center.biz.remoteservice;

import cn.com.duiba.order.center.api.remoteservice.RemoteOrderJumpService;
import cn.com.duiba.order.center.biz.service.mainorder.orderconsumer.OrderJumpService;
import cn.com.duiba.service.exception.BusinessException;
import cn.com.duiba.wolf.dubbo.DubboResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;


/**
 * Created by yansen on 16/9/21.
 */
@Service
public class RemoteOrderJumpServiceImpl implements RemoteOrderJumpService {

    @Autowired
    private OrderJumpService orderJumpService;

    /**
     * 创建订单started->兑吧付款complete
     *
     * @param orderId
     * @param consumerId
     */
    @Override
    public DubboResult<Integer> jumpCreateStarted2DuibaPayComplete(Long orderId, Long consumerId) {
        try {
            int ret=orderJumpService.jumpCreateStarted2DuibaPayComplete(orderId,consumerId);
            return DubboResult.successResult(ret);
        } catch (BusinessException e) {
            return DubboResult.failResult(e.getMessage());
        }
    }

    /**
     * 创建订单started->开发都付款完成 complete
     *
     * @param orderId
     * @param consumerId
     */
    @Override
    public DubboResult<Integer> jumpCreateStarted2DeveloperPayComplete(Long orderId, Long consumerId) {
        try {
            int ret=orderJumpService.jumpCreateStarted2DeveloperPayComplete(orderId,consumerId);
            return DubboResult.successResult(ret);
        } catch (BusinessException e) {
            return DubboResult.failResult(e.getMessage());
        }
    }

    /**
     * 开发者付款  started-> 兑吧付款完成 complete
     *
     * @param orderId
     * @param consumerId
     */
    @Override
    public DubboResult<Integer> jumpDeveloperPayStarted2DuibaPayComplete(Long orderId, Long consumerId) {
        try {
            int ret=orderJumpService.jumpDeveloperPayStarted2DuibaPayComplete(orderId,consumerId);
            return DubboResult.successResult(ret);
        } catch (BusinessException e) {
            return DubboResult.failResult(e.getMessage());
        }
    }

    /**
     * 扣积分started->用户付款complete
     *
     * @param orderId
     * @param consumerId
     */
    @Override
    public DubboResult<Integer> jumpConsumeCreditsStarted2ConsumerPayComplete(Long orderId, Long consumerId) {
        try {
            int ret=orderJumpService.jumpConsumeCreditsStarted2ConsumerPayComplete(orderId,consumerId);
            return DubboResult.successResult(ret);
        } catch (BusinessException e) {
            return DubboResult.failResult(e.getMessage());
        }
    }

    /**
     * 扣积分started->审核complete
     *
     * @param orderId
     * @param consumerId
     */
    @Override
    public DubboResult<Integer> jumpConsumeCreditsStarted2AuditComplete(Long orderId, Long consumerId) {
        try {
            int ret=orderJumpService.jumpConsumeCreditsStarted2AuditComplete(orderId,consumerId);
            return DubboResult.successResult(ret);
        } catch (BusinessException e) {
            return DubboResult.failResult(e.getMessage());
        }
    }

    /**
     * 上游兑换started->售后complete
     *
     * @param orderId
     * @param consumerId
     */
    @Override
    public DubboResult<Integer> jumpSupplierExchangeStarted2AfterSendComplete(Long orderId, Long consumerId) {
        try {
            int ret=orderJumpService.jumpSupplierExchangeStarted2AfterSendComplete(orderId,consumerId);
            return DubboResult.successResult(ret);
        } catch (BusinessException e) {
            return DubboResult.failResult(e.getMessage());
        }
    }
}
